<?php
/*
Simple:Press Forum
Global ahah loader support
$LastChangedDate: 2009-11-24 02:33:54 -0700 (Tue, 24 Nov 2009) $
$Rev: 3019 $
*/

if(preg_match('#' . basename(__FILE__) . '#', $_SERVER['PHP_SELF'])) {
	die('Access Denied');
}

# ------------------------------------------------------------------
# sfa_admin_ahah_support()
#
# Loads admin constants and includes to support AHAH calls
# ------------------------------------------------------------------
function sfa_admin_ahah_support()
{
	sf_setup_sitewide_constants();
	sf_setup_global_constants();
	sf_setup_admin_constants();
	sf_setup_global_includes();
	sf_setup_admin_includes();
}

# ------------------------------------------------------------------
# sf_forum_ahah_support()
#
# Loads forum constants and includes to support AHAH calls
# ------------------------------------------------------------------
function sf_forum_ahah_support()
{
	sf_setup_sitewide_constants();
	sf_setup_global_constants();
	sf_setup_forum_constants();
	sf_setup_global_includes();
	sf_setup_ahah_includes();
}

?>